import { Inertia } from '@inertiajs/inertia';
import { createMessage } from '@formkit/core';

const loadingMessage = createMessage({
    key: 'loading',
    visible: false,
    value: true,
});
const injectNode = (node, options) => {
    const mergedOptions = { ...options };
    if (mergedOptions?.onCancelToken) {
        mergedOptions.onCancelToken = ({ cancel }) => options?.onCancelToken?.(cancel, node);
    }
    if (mergedOptions?.onCancel) {
        mergedOptions.onCancel = () => options?.onCancel?.(node);
    }
    if (mergedOptions?.onSuccess) {
        mergedOptions.onSuccess = (page) => options?.onSuccess?.(page, node);
    }
    if (mergedOptions?.onBefore) {
        mergedOptions.onBefore = (visit) => options?.onBefore?.(visit, node);
    }
    mergedOptions.onStart = (visit) => {
        if (!options?.disableLoading)
            node.store.set(loadingMessage);
        if (!options?.disableDisabled)
            node.props.disabled = true;
        if (options?.onStart)
            return options.onStart(visit, node);
    };
    mergedOptions.onProgress = (progress) => {
        if (!options?.disableProgress && node.context)
            node.context.attrs = { 'data-progress': progress?.total };
        if (options?.onProgress)
            return options.onProgress(progress, node);
    };
    mergedOptions.onFinish = (visit) => {
        if (!options?.disableLoading)
            node.store.remove('loading');
        if (!options?.disableDisabled)
            node.props.disabled = false;
        if (!options?.disableProgress && node.context && node.context.attrs['data-progress'])
            delete node.context.attrs['data-progress'];
        if (options?.onFinish)
            return options.onFinish(visit, node);
    };
    mergedOptions.onError = (errors) => {
        if (!options?.disableErrors)
            node.setErrors([], errors);
        if (options?.onError)
            return options.onError(errors, node);
    };
    return mergedOptions;
};
const useInertia = (formNode) => {
    return {
        visit: (url, options) => Inertia.visit(url, injectNode(formNode, options)),
        get: (url, data, options) => Inertia.get(url, data, injectNode(formNode, options)),
        post: (url, data, options) => Inertia.post(url, data, injectNode(formNode, options)),
        put: (url, data, options) => Inertia.put(url, data, injectNode(formNode, options)),
        patch: (url, data, options) => Inertia.patch(url, data, injectNode(formNode, options)),
        delete: (url, options) => Inertia.delete(url, injectNode(formNode, options)),
        reload: (options) => Inertia.reload(injectNode(formNode, options)),
    };
};

const plugin = (node) => {
    if (node.props.type !== 'form' || !node.context)
        return false;
    if (node.context)
        node.context.inertia = useInertia(node);
};

export { plugin, useInertia };
//# sourceMappingURL=index.esm.js.map
